# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ozonmp/rcn_production_facade/v1/rcn_production_facade.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;ozonmp/rcn_production_facade/v1/rcn_production_facade.proto\x12\x1fozonmp.rcn_production_facade.v1\x1a\x17validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"1\n\x16GetProductionV1Request\x12\x17\n\x02id\x18\x01 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02 \x00R\x02id\"f\n\x17GetProductionV1Response\x12K\n\nproduction\x18\x01 \x01(\x0b\x32+.ozonmp.rcn_production_facade.v1.ProductionR\nproduction\"G\n\x17ListProductionV1Request\x12\x14\n\x05limit\x18\x01 \x01(\x04R\x05limit\x12\x16\n\x06offset\x18\x02 \x01(\x04R\x06offset\"i\n\x18ListProductionV1Response\x12M\n\x0bproductions\x18\x01 \x03(\x0b\x32+.ozonmp.rcn_production_facade.v1.ProductionR\x0bproductions\"\xfb\x01\n\nProduction\x12\x17\n\x02id\x18\x01 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02 \x00R\x02id\x12\x14\n\x05title\x18\x02 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06rating\x18\x04 \x01(\x03R\x06rating\x12\x18\n\x07removed\x18\x05 \x01(\x08R\x07removed\x12\x34\n\x07\x63reated\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x63reated\x12\x34\n\x07updated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07updated2\xe4\x02\n\x1aRcnProductionFacadeService\x12\xa2\x01\n\x0fGetProductionV1\x12\x37.ozonmp.rcn_production_facade.v1.GetProductionV1Request\x1a\x38.ozonmp.rcn_production_facade.v1.GetProductionV1Response\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/productions/{id}\x12\xa0\x01\n\x10ListProductionV1\x12\x38.ozonmp.rcn_production_facade.v1.ListProductionV1Request\x1a\x39.ozonmp.rcn_production_facade.v1.ListProductionV1Response\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/productionsBVZTgithub.com/ozonmp/rcn-production-api/pkg/rcn-production-facade;rcn_production_facadeb\x06proto3')



_GETPRODUCTIONV1REQUEST = DESCRIPTOR.message_types_by_name['GetProductionV1Request']
_GETPRODUCTIONV1RESPONSE = DESCRIPTOR.message_types_by_name['GetProductionV1Response']
_LISTPRODUCTIONV1REQUEST = DESCRIPTOR.message_types_by_name['ListProductionV1Request']
_LISTPRODUCTIONV1RESPONSE = DESCRIPTOR.message_types_by_name['ListProductionV1Response']
_PRODUCTION = DESCRIPTOR.message_types_by_name['Production']
GetProductionV1Request = _reflection.GeneratedProtocolMessageType('GetProductionV1Request', (_message.Message,), {
  'DESCRIPTOR' : _GETPRODUCTIONV1REQUEST,
  '__module__' : 'ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_facade.v1.GetProductionV1Request)
  })
_sym_db.RegisterMessage(GetProductionV1Request)

GetProductionV1Response = _reflection.GeneratedProtocolMessageType('GetProductionV1Response', (_message.Message,), {
  'DESCRIPTOR' : _GETPRODUCTIONV1RESPONSE,
  '__module__' : 'ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_facade.v1.GetProductionV1Response)
  })
_sym_db.RegisterMessage(GetProductionV1Response)

ListProductionV1Request = _reflection.GeneratedProtocolMessageType('ListProductionV1Request', (_message.Message,), {
  'DESCRIPTOR' : _LISTPRODUCTIONV1REQUEST,
  '__module__' : 'ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_facade.v1.ListProductionV1Request)
  })
_sym_db.RegisterMessage(ListProductionV1Request)

ListProductionV1Response = _reflection.GeneratedProtocolMessageType('ListProductionV1Response', (_message.Message,), {
  'DESCRIPTOR' : _LISTPRODUCTIONV1RESPONSE,
  '__module__' : 'ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_facade.v1.ListProductionV1Response)
  })
_sym_db.RegisterMessage(ListProductionV1Response)

Production = _reflection.GeneratedProtocolMessageType('Production', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTION,
  '__module__' : 'ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_facade.v1.Production)
  })
_sym_db.RegisterMessage(Production)

_RCNPRODUCTIONFACADESERVICE = DESCRIPTOR.services_by_name['RcnProductionFacadeService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZTgithub.com/ozonmp/rcn-production-api/pkg/rcn-production-facade;rcn_production_facade'
  _GETPRODUCTIONV1REQUEST.fields_by_name['id']._options = None
  _GETPRODUCTIONV1REQUEST.fields_by_name['id']._serialized_options = b'\372B\0042\002 \000'
  _PRODUCTION.fields_by_name['id']._options = None
  _PRODUCTION.fields_by_name['id']._serialized_options = b'\372B\0042\002 \000'
  _RCNPRODUCTIONFACADESERVICE.methods_by_name['GetProductionV1']._options = None
  _RCNPRODUCTIONFACADESERVICE.methods_by_name['GetProductionV1']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/productions/{id}'
  _RCNPRODUCTIONFACADESERVICE.methods_by_name['ListProductionV1']._options = None
  _RCNPRODUCTIONFACADESERVICE.methods_by_name['ListProductionV1']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/productions'
  _GETPRODUCTIONV1REQUEST._serialized_start=184
  _GETPRODUCTIONV1REQUEST._serialized_end=233
  _GETPRODUCTIONV1RESPONSE._serialized_start=235
  _GETPRODUCTIONV1RESPONSE._serialized_end=337
  _LISTPRODUCTIONV1REQUEST._serialized_start=339
  _LISTPRODUCTIONV1REQUEST._serialized_end=410
  _LISTPRODUCTIONV1RESPONSE._serialized_start=412
  _LISTPRODUCTIONV1RESPONSE._serialized_end=517
  _PRODUCTION._serialized_start=520
  _PRODUCTION._serialized_end=771
  _RCNPRODUCTIONFACADESERVICE._serialized_start=774
  _RCNPRODUCTIONFACADESERVICE._serialized_end=1130
# @@protoc_insertion_point(module_scope)



# Generated by the Protocol Buffers compiler. DO NOT EDIT!
# source: ozonmp/rcn_production_facade/v1/rcn_production_facade.proto
# plugin: grpclib.plugin.main
import abc
import typing

import grpclib.const
import grpclib.client
if typing.TYPE_CHECKING:
    import grpclib.server

import validate.validate_pb2
import google.api.annotations_pb2
import google.protobuf.timestamp_pb2
import ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2


class RcnProductionFacadeServiceBase(abc.ABC):

    @abc.abstractmethod
    async def GetProductionV1(self, stream: 'grpclib.server.Stream[ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2.GetProductionV1Request, ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2.GetProductionV1Response]') -> None:
        pass

    @abc.abstractmethod
    async def ListProductionV1(self, stream: 'grpclib.server.Stream[ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2.ListProductionV1Request, ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2.ListProductionV1Response]') -> None:
        pass

    def __mapping__(self) -> typing.Dict[str, grpclib.const.Handler]:
        return {
            '/ozonmp.rcn_production_facade.v1.RcnProductionFacadeService/GetProductionV1': grpclib.const.Handler(
                self.GetProductionV1,
                grpclib.const.Cardinality.UNARY_UNARY,
                ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2.GetProductionV1Request,
                ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2.GetProductionV1Response,
            ),
            '/ozonmp.rcn_production_facade.v1.RcnProductionFacadeService/ListProductionV1': grpclib.const.Handler(
                self.ListProductionV1,
                grpclib.const.Cardinality.UNARY_UNARY,
                ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2.ListProductionV1Request,
                ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2.ListProductionV1Response,
            ),
        }


class RcnProductionFacadeServiceStub:

    def __init__(self, channel: grpclib.client.Channel) -> None:
        self.GetProductionV1 = grpclib.client.UnaryUnaryMethod(
            channel,
            '/ozonmp.rcn_production_facade.v1.RcnProductionFacadeService/GetProductionV1',
            ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2.GetProductionV1Request,
            ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2.GetProductionV1Response,
        )
        self.ListProductionV1 = grpclib.client.UnaryUnaryMethod(
            channel,
            '/ozonmp.rcn_production_facade.v1.RcnProductionFacadeService/ListProductionV1',
            ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2.ListProductionV1Request,
            ozonmp.rcn_production_facade.v1.rcn_production_facade_pb2.ListProductionV1Response,
        )



# Generated by the Protocol Buffers compiler. DO NOT EDIT!
# source: ozonmp/rcn_production_api/v1/rcn_production_api.proto
# plugin: grpclib.plugin.main
import abc
import typing

import grpclib.const
import grpclib.client
if typing.TYPE_CHECKING:
    import grpclib.server

import validate.validate_pb2
import google.api.annotations_pb2
import google.protobuf.timestamp_pb2
import ozonmp.rcn_production_api.v1.rcn_production_api_pb2


class RcnProductionApiServiceBase(abc.ABC):

    @abc.abstractmethod
    async def AddProductionV1(self, stream: 'grpclib.server.Stream[ozonmp.rcn_production_api.v1.rcn_production_api_pb2.AddProductionV1Request, ozonmp.rcn_production_api.v1.rcn_production_api_pb2.AddProductionV1Response]') -> None:
        pass

    @abc.abstractmethod
    async def UpdateProductionV1(self, stream: 'grpclib.server.Stream[ozonmp.rcn_production_api.v1.rcn_production_api_pb2.UpdateProductionV1Request, ozonmp.rcn_production_api.v1.rcn_production_api_pb2.UpdateProductionV1Response]') -> None:
        pass

    @abc.abstractmethod
    async def GetProductionV1(self, stream: 'grpclib.server.Stream[ozonmp.rcn_production_api.v1.rcn_production_api_pb2.GetProductionV1Request, ozonmp.rcn_production_api.v1.rcn_production_api_pb2.GetProductionV1Response]') -> None:
        pass

    @abc.abstractmethod
    async def ListProductionV1(self, stream: 'grpclib.server.Stream[ozonmp.rcn_production_api.v1.rcn_production_api_pb2.ListProductionV1Request, ozonmp.rcn_production_api.v1.rcn_production_api_pb2.ListProductionV1Response]') -> None:
        pass

    @abc.abstractmethod
    async def RemoveProductionV1(self, stream: 'grpclib.server.Stream[ozonmp.rcn_production_api.v1.rcn_production_api_pb2.RemoveProductionV1Request, ozonmp.rcn_production_api.v1.rcn_production_api_pb2.RemoveProductionV1Response]') -> None:
        pass

    def __mapping__(self) -> typing.Dict[str, grpclib.const.Handler]:
        return {
            '/ozonmp.rcn_production_api.v1.RcnProductionApiService/AddProductionV1': grpclib.const.Handler(
                self.AddProductionV1,
                grpclib.const.Cardinality.UNARY_UNARY,
                ozonmp.rcn_production_api.v1.rcn_production_api_pb2.AddProductionV1Request,
                ozonmp.rcn_production_api.v1.rcn_production_api_pb2.AddProductionV1Response,
            ),
            '/ozonmp.rcn_production_api.v1.RcnProductionApiService/UpdateProductionV1': grpclib.const.Handler(
                self.UpdateProductionV1,
                grpclib.const.Cardinality.UNARY_UNARY,
                ozonmp.rcn_production_api.v1.rcn_production_api_pb2.UpdateProductionV1Request,
                ozonmp.rcn_production_api.v1.rcn_production_api_pb2.UpdateProductionV1Response,
            ),
            '/ozonmp.rcn_production_api.v1.RcnProductionApiService/GetProductionV1': grpclib.const.Handler(
                self.GetProductionV1,
                grpclib.const.Cardinality.UNARY_UNARY,
                ozonmp.rcn_production_api.v1.rcn_production_api_pb2.GetProductionV1Request,
                ozonmp.rcn_production_api.v1.rcn_production_api_pb2.GetProductionV1Response,
            ),
            '/ozonmp.rcn_production_api.v1.RcnProductionApiService/ListProductionV1': grpclib.const.Handler(
                self.ListProductionV1,
                grpclib.const.Cardinality.UNARY_UNARY,
                ozonmp.rcn_production_api.v1.rcn_production_api_pb2.ListProductionV1Request,
                ozonmp.rcn_production_api.v1.rcn_production_api_pb2.ListProductionV1Response,
            ),
            '/ozonmp.rcn_production_api.v1.RcnProductionApiService/RemoveProductionV1': grpclib.const.Handler(
                self.RemoveProductionV1,
                grpclib.const.Cardinality.UNARY_UNARY,
                ozonmp.rcn_production_api.v1.rcn_production_api_pb2.RemoveProductionV1Request,
                ozonmp.rcn_production_api.v1.rcn_production_api_pb2.RemoveProductionV1Response,
            ),
        }


class RcnProductionApiServiceStub:

    def __init__(self, channel: grpclib.client.Channel) -> None:
        self.AddProductionV1 = grpclib.client.UnaryUnaryMethod(
            channel,
            '/ozonmp.rcn_production_api.v1.RcnProductionApiService/AddProductionV1',
            ozonmp.rcn_production_api.v1.rcn_production_api_pb2.AddProductionV1Request,
            ozonmp.rcn_production_api.v1.rcn_production_api_pb2.AddProductionV1Response,
        )
        self.UpdateProductionV1 = grpclib.client.UnaryUnaryMethod(
            channel,
            '/ozonmp.rcn_production_api.v1.RcnProductionApiService/UpdateProductionV1',
            ozonmp.rcn_production_api.v1.rcn_production_api_pb2.UpdateProductionV1Request,
            ozonmp.rcn_production_api.v1.rcn_production_api_pb2.UpdateProductionV1Response,
        )
        self.GetProductionV1 = grpclib.client.UnaryUnaryMethod(
            channel,
            '/ozonmp.rcn_production_api.v1.RcnProductionApiService/GetProductionV1',
            ozonmp.rcn_production_api.v1.rcn_production_api_pb2.GetProductionV1Request,
            ozonmp.rcn_production_api.v1.rcn_production_api_pb2.GetProductionV1Response,
        )
        self.ListProductionV1 = grpclib.client.UnaryUnaryMethod(
            channel,
            '/ozonmp.rcn_production_api.v1.RcnProductionApiService/ListProductionV1',
            ozonmp.rcn_production_api.v1.rcn_production_api_pb2.ListProductionV1Request,
            ozonmp.rcn_production_api.v1.rcn_production_api_pb2.ListProductionV1Response,
        )
        self.RemoveProductionV1 = grpclib.client.UnaryUnaryMethod(
            channel,
            '/ozonmp.rcn_production_api.v1.RcnProductionApiService/RemoveProductionV1',
            ozonmp.rcn_production_api.v1.rcn_production_api_pb2.RemoveProductionV1Request,
            ozonmp.rcn_production_api.v1.rcn_production_api_pb2.RemoveProductionV1Response,
        )



from setuptools import setup, find_packages

setup(
    name="rcn-production-api",
    version="0.0.1",
    author="nikitacrit (Nikita Sidorov)",
    author_email="nikitacrit@mail.ru",
    description="Recommendation production api proto client lib",
    packages=find_packages()
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ozonmp/rcn_production_api/v1/rcn_production_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ozonmp/rcn_production_api/v1/rcn_production_api.proto\x12\x1cozonmp.rcn_production_api.v1\x1a\x17validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"h\n\x16\x41\x64\x64ProductionV1Request\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06rating\x18\x03 \x01(\x03R\x06rating\"c\n\x17\x41\x64\x64ProductionV1Response\x12H\n\nproduction\x18\x01 \x01(\x0b\x32(.ozonmp.rcn_production_api.v1.ProductionR\nproduction\"\x84\x01\n\x19UpdateProductionV1Request\x12\x17\n\x02id\x18\x01 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02 \x00R\x02id\x12\x14\n\x05title\x18\x02 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06rating\x18\x04 \x01(\x03R\x06rating\"f\n\x1aUpdateProductionV1Response\x12H\n\nproduction\x18\x01 \x01(\x0b\x32(.ozonmp.rcn_production_api.v1.ProductionR\nproduction\"1\n\x16GetProductionV1Request\x12\x17\n\x02id\x18\x01 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02 \x00R\x02id\"c\n\x17GetProductionV1Response\x12H\n\nproduction\x18\x01 \x01(\x0b\x32(.ozonmp.rcn_production_api.v1.ProductionR\nproduction\"G\n\x17ListProductionV1Request\x12\x14\n\x05limit\x18\x01 \x01(\x04R\x05limit\x12\x16\n\x06offset\x18\x02 \x01(\x04R\x06offset\"f\n\x18ListProductionV1Response\x12J\n\x0bproductions\x18\x01 \x03(\x0b\x32(.ozonmp.rcn_production_api.v1.ProductionR\x0bproductions\"4\n\x19RemoveProductionV1Request\x12\x17\n\x02id\x18\x01 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02 \x00R\x02id\"f\n\x1aRemoveProductionV1Response\x12H\n\nproduction\x18\x01 \x01(\x0b\x32(.ozonmp.rcn_production_api.v1.ProductionR\nproduction\"\xfb\x01\n\nProduction\x12\x17\n\x02id\x18\x01 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02 \x00R\x02id\x12\x14\n\x05title\x18\x02 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06rating\x18\x04 \x01(\x03R\x06rating\x12\x18\n\x07removed\x18\x05 \x01(\x08R\x07removed\x12\x34\n\x07\x63reated\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x63reated\x12\x34\n\x07updated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07updated\"\xba\x04\n\x0fProductionEvent\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12\x46\n\x04type\x18\x02 \x01(\x0e\x32\x32.ozonmp.rcn_production_api.v1.ProductionEvent.TypeR\x04type\x12L\n\x06status\x18\x03 \x01(\x0e\x32\x34.ozonmp.rcn_production_api.v1.ProductionEvent.StatusR\x06status\x12H\n\nproduction\x18\x04 \x01(\x0b\x32(.ozonmp.rcn_production_api.v1.ProductionR\nproduction\x12\x34\n\x07updated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07updated\"\xa1\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cTYPE_CREATED\x10\x01\x12\x10\n\x0cTYPE_REMOVED\x10\x02\x12\x10\n\x0cTYPE_UPDATED\x10\x03\x12\x16\n\x12TYPE_UPDATED_TITLE\x10\x04\x12\x1c\n\x18TYPE_UPDATED_DESCRIPTION\x10\x05\x12\x17\n\x13TYPE_UPDATED_RATING\x10\x06\"]\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0e\n\nSTATUS_NEW\x10\x01\x12\x15\n\x11STATUS_PROCESSING\x10\x02\x12\x14\n\x10STATUS_PROCESSED\x10\x03\x32\xc5\x06\n\x17RcnProductionApiService\x12\x9a\x01\n\x0f\x41\x64\x64ProductionV1\x12\x34.ozonmp.rcn_production_api.v1.AddProductionV1Request\x1a\x35.ozonmp.rcn_production_api.v1.AddProductionV1Response\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/productions:\x01*\x12\xa8\x01\n\x12UpdateProductionV1\x12\x37.ozonmp.rcn_production_api.v1.UpdateProductionV1Request\x1a\x38.ozonmp.rcn_production_api.v1.UpdateProductionV1Response\"\x1f\x82\xd3\xe4\x93\x02\x19\x1a\x14/v1/productions/{id}:\x01*\x12\x9c\x01\n\x0fGetProductionV1\x12\x34.ozonmp.rcn_production_api.v1.GetProductionV1Request\x1a\x35.ozonmp.rcn_production_api.v1.GetProductionV1Response\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/productions/{id}\x12\x9a\x01\n\x10ListProductionV1\x12\x35.ozonmp.rcn_production_api.v1.ListProductionV1Request\x1a\x36.ozonmp.rcn_production_api.v1.ListProductionV1Response\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/productions\x12\xa5\x01\n\x12RemoveProductionV1\x12\x37.ozonmp.rcn_production_api.v1.RemoveProductionV1Request\x1a\x38.ozonmp.rcn_production_api.v1.RemoveProductionV1Response\"\x1c\x82\xd3\xe4\x93\x02\x16*\x14/v1/productions/{id}BPZNgithub.com/ozonmp/rcn-production-api/pkg/rcn-production-api;rcn_production_apib\x06proto3')



_ADDPRODUCTIONV1REQUEST = DESCRIPTOR.message_types_by_name['AddProductionV1Request']
_ADDPRODUCTIONV1RESPONSE = DESCRIPTOR.message_types_by_name['AddProductionV1Response']
_UPDATEPRODUCTIONV1REQUEST = DESCRIPTOR.message_types_by_name['UpdateProductionV1Request']
_UPDATEPRODUCTIONV1RESPONSE = DESCRIPTOR.message_types_by_name['UpdateProductionV1Response']
_GETPRODUCTIONV1REQUEST = DESCRIPTOR.message_types_by_name['GetProductionV1Request']
_GETPRODUCTIONV1RESPONSE = DESCRIPTOR.message_types_by_name['GetProductionV1Response']
_LISTPRODUCTIONV1REQUEST = DESCRIPTOR.message_types_by_name['ListProductionV1Request']
_LISTPRODUCTIONV1RESPONSE = DESCRIPTOR.message_types_by_name['ListProductionV1Response']
_REMOVEPRODUCTIONV1REQUEST = DESCRIPTOR.message_types_by_name['RemoveProductionV1Request']
_REMOVEPRODUCTIONV1RESPONSE = DESCRIPTOR.message_types_by_name['RemoveProductionV1Response']
_PRODUCTION = DESCRIPTOR.message_types_by_name['Production']
_PRODUCTIONEVENT = DESCRIPTOR.message_types_by_name['ProductionEvent']
_PRODUCTIONEVENT_TYPE = _PRODUCTIONEVENT.enum_types_by_name['Type']
_PRODUCTIONEVENT_STATUS = _PRODUCTIONEVENT.enum_types_by_name['Status']
AddProductionV1Request = _reflection.GeneratedProtocolMessageType('AddProductionV1Request', (_message.Message,), {
  'DESCRIPTOR' : _ADDPRODUCTIONV1REQUEST,
  '__module__' : 'ozonmp.rcn_production_api.v1.rcn_production_api_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_api.v1.AddProductionV1Request)
  })
_sym_db.RegisterMessage(AddProductionV1Request)

AddProductionV1Response = _reflection.GeneratedProtocolMessageType('AddProductionV1Response', (_message.Message,), {
  'DESCRIPTOR' : _ADDPRODUCTIONV1RESPONSE,
  '__module__' : 'ozonmp.rcn_production_api.v1.rcn_production_api_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_api.v1.AddProductionV1Response)
  })
_sym_db.RegisterMessage(AddProductionV1Response)

UpdateProductionV1Request = _reflection.GeneratedProtocolMessageType('UpdateProductionV1Request', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPRODUCTIONV1REQUEST,
  '__module__' : 'ozonmp.rcn_production_api.v1.rcn_production_api_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_api.v1.UpdateProductionV1Request)
  })
_sym_db.RegisterMessage(UpdateProductionV1Request)

UpdateProductionV1Response = _reflection.GeneratedProtocolMessageType('UpdateProductionV1Response', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPRODUCTIONV1RESPONSE,
  '__module__' : 'ozonmp.rcn_production_api.v1.rcn_production_api_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_api.v1.UpdateProductionV1Response)
  })
_sym_db.RegisterMessage(UpdateProductionV1Response)

GetProductionV1Request = _reflection.GeneratedProtocolMessageType('GetProductionV1Request', (_message.Message,), {
  'DESCRIPTOR' : _GETPRODUCTIONV1REQUEST,
  '__module__' : 'ozonmp.rcn_production_api.v1.rcn_production_api_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_api.v1.GetProductionV1Request)
  })
_sym_db.RegisterMessage(GetProductionV1Request)

GetProductionV1Response = _reflection.GeneratedProtocolMessageType('GetProductionV1Response', (_message.Message,), {
  'DESCRIPTOR' : _GETPRODUCTIONV1RESPONSE,
  '__module__' : 'ozonmp.rcn_production_api.v1.rcn_production_api_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_api.v1.GetProductionV1Response)
  })
_sym_db.RegisterMessage(GetProductionV1Response)

ListProductionV1Request = _reflection.GeneratedProtocolMessageType('ListProductionV1Request', (_message.Message,), {
  'DESCRIPTOR' : _LISTPRODUCTIONV1REQUEST,
  '__module__' : 'ozonmp.rcn_production_api.v1.rcn_production_api_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_api.v1.ListProductionV1Request)
  })
_sym_db.RegisterMessage(ListProductionV1Request)

ListProductionV1Response = _reflection.GeneratedProtocolMessageType('ListProductionV1Response', (_message.Message,), {
  'DESCRIPTOR' : _LISTPRODUCTIONV1RESPONSE,
  '__module__' : 'ozonmp.rcn_production_api.v1.rcn_production_api_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_api.v1.ListProductionV1Response)
  })
_sym_db.RegisterMessage(ListProductionV1Response)

RemoveProductionV1Request = _reflection.GeneratedProtocolMessageType('RemoveProductionV1Request', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPRODUCTIONV1REQUEST,
  '__module__' : 'ozonmp.rcn_production_api.v1.rcn_production_api_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_api.v1.RemoveProductionV1Request)
  })
_sym_db.RegisterMessage(RemoveProductionV1Request)

RemoveProductionV1Response = _reflection.GeneratedProtocolMessageType('RemoveProductionV1Response', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPRODUCTIONV1RESPONSE,
  '__module__' : 'ozonmp.rcn_production_api.v1.rcn_production_api_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_api.v1.RemoveProductionV1Response)
  })
_sym_db.RegisterMessage(RemoveProductionV1Response)

Production = _reflection.GeneratedProtocolMessageType('Production', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTION,
  '__module__' : 'ozonmp.rcn_production_api.v1.rcn_production_api_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_api.v1.Production)
  })
_sym_db.RegisterMessage(Production)

ProductionEvent = _reflection.GeneratedProtocolMessageType('ProductionEvent', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTIONEVENT,
  '__module__' : 'ozonmp.rcn_production_api.v1.rcn_production_api_pb2'
  # @@protoc_insertion_point(class_scope:ozonmp.rcn_production_api.v1.ProductionEvent)
  })
_sym_db.RegisterMessage(ProductionEvent)

_RCNPRODUCTIONAPISERVICE = DESCRIPTOR.services_by_name['RcnProductionApiService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/ozonmp/rcn-production-api/pkg/rcn-production-api;rcn_production_api'
  _UPDATEPRODUCTIONV1REQUEST.fields_by_name['id']._options = None
  _UPDATEPRODUCTIONV1REQUEST.fields_by_name['id']._serialized_options = b'\372B\0042\002 \000'
  _GETPRODUCTIONV1REQUEST.fields_by_name['id']._options = None
  _GETPRODUCTIONV1REQUEST.fields_by_name['id']._serialized_options = b'\372B\0042\002 \000'
  _REMOVEPRODUCTIONV1REQUEST.fields_by_name['id']._options = None
  _REMOVEPRODUCTIONV1REQUEST.fields_by_name['id']._serialized_options = b'\372B\0042\002 \000'
  _PRODUCTION.fields_by_name['id']._options = None
  _PRODUCTION.fields_by_name['id']._serialized_options = b'\372B\0042\002 \000'
  _RCNPRODUCTIONAPISERVICE.methods_by_name['AddProductionV1']._options = None
  _RCNPRODUCTIONAPISERVICE.methods_by_name['AddProductionV1']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/productions:\001*'
  _RCNPRODUCTIONAPISERVICE.methods_by_name['UpdateProductionV1']._options = None
  _RCNPRODUCTIONAPISERVICE.methods_by_name['UpdateProductionV1']._serialized_options = b'\202\323\344\223\002\031\032\024/v1/productions/{id}:\001*'
  _RCNPRODUCTIONAPISERVICE.methods_by_name['GetProductionV1']._options = None
  _RCNPRODUCTIONAPISERVICE.methods_by_name['GetProductionV1']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/productions/{id}'
  _RCNPRODUCTIONAPISERVICE.methods_by_name['ListProductionV1']._options = None
  _RCNPRODUCTIONAPISERVICE.methods_by_name['ListProductionV1']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/productions'
  _RCNPRODUCTIONAPISERVICE.methods_by_name['RemoveProductionV1']._options = None
  _RCNPRODUCTIONAPISERVICE.methods_by_name['RemoveProductionV1']._serialized_options = b'\202\323\344\223\002\026*\024/v1/productions/{id}'
  _ADDPRODUCTIONV1REQUEST._serialized_start=175
  _ADDPRODUCTIONV1REQUEST._serialized_end=279
  _ADDPRODUCTIONV1RESPONSE._serialized_start=281
  _ADDPRODUCTIONV1RESPONSE._serialized_end=380
  _UPDATEPRODUCTIONV1REQUEST._serialized_start=383
  _UPDATEPRODUCTIONV1REQUEST._serialized_end=515
  _UPDATEPRODUCTIONV1RESPONSE._serialized_start=517
  _UPDATEPRODUCTIONV1RESPONSE._serialized_end=619
  _GETPRODUCTIONV1REQUEST._serialized_start=621
  _GETPRODUCTIONV1REQUEST._serialized_end=670
  _GETPRODUCTIONV1RESPONSE._serialized_start=672
  _GETPRODUCTIONV1RESPONSE._serialized_end=771
  _LISTPRODUCTIONV1REQUEST._serialized_start=773
  _LISTPRODUCTIONV1REQUEST._serialized_end=844
  _LISTPRODUCTIONV1RESPONSE._serialized_start=846
  _LISTPRODUCTIONV1RESPONSE._serialized_end=948
  _REMOVEPRODUCTIONV1REQUEST._serialized_start=950
  _REMOVEPRODUCTIONV1REQUEST._serialized_end=1002
  _REMOVEPRODUCTIONV1RESPONSE._serialized_start=1004
  _REMOVEPRODUCTIONV1RESPONSE._serialized_end=1106
  _PRODUCTION._serialized_start=1109
  _PRODUCTION._serialized_end=1360
  _PRODUCTIONEVENT._serialized_start=1363
  _PRODUCTIONEVENT._serialized_end=1933
  _PRODUCTIONEVENT_TYPE._serialized_start=1677
  _PRODUCTIONEVENT_TYPE._serialized_end=1838
  _PRODUCTIONEVENT_STATUS._serialized_start=1840
  _PRODUCTIONEVENT_STATUS._serialized_end=1933
  _RCNPRODUCTIONAPISERVICE._serialized_start=1936
  _RCNPRODUCTIONAPISERVICE._serialized_end=2773
# @@protoc_insertion_point(module_scope)
